summaryrefslogtreecommitdiff
path: root/actions/twitapigroups.php
diff options
context:
space:
mode:
Diffstat (limited to 'actions/twitapigroups.php')
-rw-r--r--actions/twitapigroups.php32
1 files changed, 16 insertions, 16 deletions
diff --git a/actions/twitapigroups.php b/actions/twitapigroups.php
index bebc07fa1..214fa8214 100644
--- a/actions/twitapigroups.php
+++ b/actions/twitapigroups.php
@@ -1,8 +1,8 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* Laconica extensions to the Twitter-like API for groups
*
* PHP version 5
*
@@ -20,15 +20,15 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Twitter
- * @package Laconica
+ * @package StatusNet
* @author Craig Andrews
- * @author Zach Copley <zach@controlyourself.ca>
- * @copyright 2009 Control Yourself, Inc.
+ * @author Zach Copley <zach@status.net>
+ * @copyright 2009 StatusNet, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
-if (!defined('LACONICA')) {
+if (!defined('STATUSNET') && !defined('LACONICA')) {
exit(1);
}
@@ -37,15 +37,15 @@ require_once INSTALLDIR.'/lib/twitterapi.php';
/**
* Group-specific API methods
*
* This class handles Laconica group API methods.
*
* @category Twitter
- * @package Laconica
+ * @package StatusNet
* @author Craig Andrews
- * @author Zach Copley <zach@controlyourself.ca>
- * @copyright 2009 Control Yourself, Inc.
+ * @author Zach Copley <zach@status.net>
+ * @copyright 2009 StatusNet, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
class TwitapigroupsAction extends TwitterapiAction
@@ -88,7 +88,7 @@ require_once INSTALLDIR.'/lib/twitterapi.php';
$this->show_rss_groups($group, $title, $link, $subtitle);
break;
case 'atom':
- $selfuri = common_root_url() . 'api/laconica/groups/list/' . $user->id . '.atom';
+ $selfuri = common_root_url() . 'api/statusnet/groups/list/' . $user->id . '.atom';
$this->show_atom_groups($group, $title, $id, $link,
$subtitle, $selfuri);
break;
@@ -135,7 +135,7 @@ require_once INSTALLDIR.'/lib/twitterapi.php';
$this->show_rss_groups($group, $title, $link, $subtitle);
break;
case 'atom':
- $selfuri = common_root_url() . 'api/laconica/groups/list_all.atom';
+ $selfuri = common_root_url() . 'api/statusnet/groups/list_all.atom';
$this->show_atom_groups($group, $title, $id, $link,
$subtitle, $selfuri);
break;
@@ -216,11 +216,11 @@ require_once INSTALLDIR.'/lib/twitterapi.php';
case 'atom':
if (isset($apidata['api_arg'])) {
$selfuri = common_root_url() .
- 'api/laconica/groups/timeline/' .
+ 'api/statusnet/groups/timeline/' .
$apidata['api_arg'] . '.atom';
} else {
$selfuri = common_root_url() .
- 'api/laconica/groups/timeline.atom';
+ 'api/statusnet/groups/timeline.atom';
}
$this->show_atom_timeline($notice, $title, $id, $link,
$subtitle, null, $selfuri);
@@ -1,8 +1,8 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
@@ -1,8 +1,8 @@
*
- * Laconica extensions to the Twitter-like API for groups
+ * StatusNet extensions to the Twitter-like API for groups
*
* PHP version 5
@@ -37,15 +37,15 @@ require_once INSTALLDIR.'/lib/twitterapi.php';
* Group-specific API methods
*
- * This class handles Laconica group API methods.
+ * This class handles StatusNet group API methods.
*
* @category Twitter